[En-Nut-Discussion] My ethernut git branch at github, mainly for devnut-m3n

Uwe Bonnes bon at elektron.ikp.physik.tu-darmstadt.de
Thu Dec 22 11:41:45 CET 2011


Hello,

with git allowing to work online and github to synchronize work on different
sites, I created a git svn branch of the sourceforge ethernut
repository. The git branch is at 

git at github.com:UweBonnes/devnut_m3n.git

At most it contains the patches already sent. 

0177-Some-hints-for-the-SVN-GIT-translation-and-for-comma.patch

is new and fixes a typo when using uart4/5

0176-Use-WFI-wait-for-interrupt-in-the-idle-thread-and-us.patch is more a
proof of concept. 

Find appended 0177. How to proceed with more patches. Post the patch? Post a
hint about the github commit?

Henrik, anything from you, I should integrate? Anybody needing write access
on github?

Otherwise: Seasins greetings!
-- 
Uwe Bonnes                bon at elektron.ikp.physik.tu-darmstadt.de

Institut fuer Kernphysik  Schlossgartenstrasse 9  64289 Darmstadt
--------- Tel. 06151 162516 -------- Fax. 06151 164321 ----------
>From e028a26737b8bf2521a321f950f595b44868db02 Mon Sep 17 00:00:00 2001
From: Uwe Bonnes <bon at elektron.ikp.physik.tu-darmstadt.de>
Date: Wed, 21 Dec 2011 20:58:27 +0100
Subject: UART4/5 have no sig_USART (versus sig_UART)

---
 nut/arch/cm3/dev/stm/ih_stm32_uart4.c |   14 +++++++-------
 nut/arch/cm3/dev/stm/ih_stm32_uart5.c |   10 +++++-----
 2 files changed, 12 insertions(+), 12 deletions(-)

diff --git a/nut/arch/cm3/dev/stm/ih_stm32_uart4.c b/nut/arch/cm3/dev/stm/ih_stm32_uart4.c
index 4fb23ab..9041c90 100644
--- a/nut/arch/cm3/dev/stm/ih_stm32_uart4.c
+++ b/nut/arch/cm3/dev/stm/ih_stm32_uart4.c
@@ -53,9 +53,9 @@ extern NUTDEVICE devUartStm32_4;
 static int Uart4IrqCtl(int cmd, void *param);
 
 /*!
  * \breif IRQ Handler for USART4.
  */
-IRQ_HANDLER sig_USART4 = {
+IRQ_HANDLER sig_UART4 = {
 #ifdef NUT_PERFMON
     0,                  /* Interrupt counter, ir_count. */
 #endif
@@ -70,10 +70,10 @@ IRQ_HANDLER sig_USART4 = {
 void Uart4IrqEntry(void *arg)
 {
 #ifdef NUT_PERFMON
-    sig_USART4.ir_count++;
+    sig_UART4.ir_count++;
 #endif
-    if (sig_USART4.ir_handler) {
-        (sig_USART4.ir_handler) (sig_USART4.ir_arg);
+    if (sig_UART4.ir_handler) {
+        (sig_UART4.ir_handler) (sig_UART4.ir_arg);
     }
 }
 
@@ -142,8 +142,8 @@ static int Uart4IrqCtl(int cmd, void *param)
         break;
 #ifdef NUT_PERFMON
     case NUT_IRQCTL_GETCOUNT:
-        *ival = (unsigned int)sig_USART4.ir_count;
-        sig_USART4.ir_count = 0;
+        *ival = (unsigned int)sig_UART4.ir_count;
+        sig_UART4.ir_count = 0;
         break;
 #endif
     default:
@@ -53,9 +53,9 @@ extern NUTDEVICE devUartStm32_4;
 
 /*!
- * \breif IRQ Handler for USART4.
+ * \breif IRQ Handler for UART4.
  */
diff --git a/nut/arch/cm3/dev/stm/ih_stm32_uart5.c b/nut/arch/cm3/dev/stm/ih_stm32_uart5.c
index 0f3cc02..bdea6f0 100644
--- a/nut/arch/cm3/dev/stm/ih_stm32_uart5.c
+++ b/nut/arch/cm3/dev/stm/ih_stm32_uart5.c
@@ -53,9 +53,9 @@ extern NUTDEVICE devUartStm32_5;
 static int Uart5IrqCtl(int cmd, void *param);
 
 /*!
  * \brief IRQ Handler for USART5.
  */
-IRQ_HANDLER sig_USART5 = {
+IRQ_HANDLER sig_UART5 = {
 #ifdef NUT_PERFMON
     0,                  /* Interrupt counter, ir_count. */
 #endif
@@ -70,10 +70,10 @@ IRQ_HANDLER sig_USART5 = {
 void Uart5IrqEntry(void *arg)
 {
 #ifdef NUT_PERFMON
-    sig_USART5.ir_count++;
+    sig_UART5.ir_count++;
 #endif
-    if (sig_USART5.ir_handler) {
-        (sig_USART5.ir_handler) (sig_USART5.ir_arg);
+    if (sig_UART5.ir_handler) {
+        (sig_UART5.ir_handler) (sig_UART5.ir_arg);
     }
 }
 
@@ -53,9 +53,9 @@ extern NUTDEVICE devUartStm32_5;
 
 /*!
- * \brief IRQ Handler for USART5.
+ * \brief IRQ Handler for UART5.
  */
-- 
1.7.3.4




More information about the En-Nut-Discussion mailing list